==> haskell-drbg-0.5.5-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-LlNnSK9KMSs5g1FwELHjng
key: DRBG-0.5.5-LlNnSK9KMSs5g1FwELHjng
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 1fbe431eb8590fe801cbb96d43e7d06c
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-LlNnSK9KMSs5g1FwELHjng
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes128-0.7.0.4-DBTDbOO07KA42MaPNe3Sf
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    cryptohash-cryptoapi-0.1.4-DMZrwu8N3By1XJDhwBzBDW
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DRBG
version: 0.5.5
id: DRBG-0.5.5-KB6gArKhNKFLiwlM2cj4NC
key: DRBG-0.5.5-KB6gArKhNKFLiwlM2cj4NC
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: Deterministic random bit generator (aka RNG, PRNG) based
          HMACs, Hashes, and Ciphers.
description:
    Cryptographically secure RNGs
category: Cryptography
abi: 1a554df04285df4eac92520f033a4918
exposed: True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types
hidden-modules: Crypto.Random.DRBG.HashDF
import-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DRBG-0.5.5
hs-libraries: HSDRBG-0.5.5-KB6gArKhNKFLiwlM2cj4NC
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes128-0.7.0.4-C7LOlaEpY3a722fuXEDhpw
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    cryptohash-cryptoapi-0.1.4-uBxsHSQ697LgWw7SvhNHC
    entropy-0.4.1.5-1eGU5wdZtMSH0Us8GoRymJ mtl-2.2.2
    parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
    prettyclass-1.0.0.0-TEwWRphxli3LO8yb54rr0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html: /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
